==> ejc-probid-api-3.0.0-20220722.030520-37-sources.jar: com/ejianc/business/bid/vo/BusinessVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 商机登记
 * 
 * @author generator
 * 
 */
public class BusinessVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String projectName; // 招标项目名称
    private String constructionUnit; // 建设单位
    private Long unitnatureId; // 建设单位 性质
    private String unitnatureName; // 建设单位 性质(name)
    private String unitnatureCode; // 建设单位 性质(name)
    private String projectScale; // 项目规模
    private BigDecimal investmentVolume; // 投资额
    private BigDecimal civilErectionCost; // 投资额
    private Long bidUnitId; // 申请单位
    private String bidUnitName; // 申请单位 名称
    private String bidUnitCode; // 申请单位 编码
    private String implementModel; // 实施模式
    private Long projectTypeId; // 项目类别
    private String projectTypeName; // 项目类别名称
    private String projectTypeCode; // 项目类型编码
    private String projectLever; // 项目跟踪等级
    private String projectLeverName; // 项目跟踪等级
    private Long sourceProjectType; // 项目来源
    private String sourceProjectTypeName; // 项目来源
    private String detailedAddress; // 详细地址
    private String area; // 区域
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date bidPlanOpenDate; // 预计开标日期
    private String projectStatus; // 项目状态
    private String employeeCode; // 项目跟踪人编码
    private String employeeName; // 项目跟踪人名称
    private String employeePhone; // 项目跟踪人电话

    private Long employeeId; // 项目跟踪人
    private String tailAfterSituation; // 项目跟踪情况
    private String projectSituation; // 项目概况
    private String billCode; // 单据编码
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Date commitData; // 提交日期
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    private Integer refFlag; // 是否被引用

    private String changeItem;

    public String getChangeItem() {
        return changeItem;
    }

    public Integer getRefFlag() {
        return refFlag;
    }

    public void setRefFlag(Integer refFlag) {
        this.refFlag = refFlag;
    }

    public String getProjectTypeCode() {
        return projectTypeCode;
    }

    public void setProjectTypeCode(String projectTypeCode) {
        this.projectTypeCode = projectTypeCode;
    }

    public void setChangeItem(String changeItem) {
        this.changeItem = changeItem;
    }

    public String getEmployeePhone() {
        return employeePhone;
    }

    public void setEmployeePhone(String employeePhone) {
        this.employeePhone = employeePhone;
    }

    private List<BusinessRecordVO> recordList = new ArrayList<>();

    public List<BusinessRecordVO> getRecordList() {
        return recordList;
    }

    public void setRecordList(List<BusinessRecordVO> recordList) {
        this.recordList = recordList;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }
    @ReferDeserialTransfer
    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public BigDecimal getInvestmentVolume() {
        return investmentVolume;
    }

    public void setInvestmentVolume(BigDecimal investmentVolume) {
        this.investmentVolume = investmentVolume;
    }
    public BigDecimal getCivilErectionCost() {
        return civilErectionCost;
    }

    public void setCivilErectionCost(BigDecimal civilErectionCost) {
        this.civilErectionCost = civilErectionCost;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }
    @ReferDeserialTransfer
    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getImplementModel() {
        return implementModel;
    }

    public void setImplementModel(String implementModel) {
        this.implementModel = implementModel;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }
    @ReferDeserialTransfer
    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProjectLever() {
        return projectLever;
    }
    public void setProjectLever(String projectLever) {
        this.projectLever = projectLever;
    }
    public String getProjectLeverName() {
        return projectLeverName;
    }

    public void setProjectLeverName(String projectLeverName) {
        this.projectLeverName = projectLeverName;
    }
    public Long getSourceProjectType() {
        return sourceProjectType;
    }
    @ReferDeserialTransfer
    public void setSourceProjectType(Long sourceProjectType) {
        this.sourceProjectType = sourceProjectType;
    }
    public String getSourceProjectTypeName() {
        return sourceProjectTypeName;
    }

    public void setSourceProjectTypeName(String sourceProjectTypeName) {
        this.sourceProjectTypeName = sourceProjectTypeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Date getBidPlanOpenDate() {
        return bidPlanOpenDate;
    }

    public void setBidPlanOpenDate(Date bidPlanOpenDate) {
        this.bidPlanOpenDate = bidPlanOpenDate;
    }
    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getTailAfterSituation() {
        return tailAfterSituation;
    }

    public void setTailAfterSituation(String tailAfterSituation) {
        this.tailAfterSituation = tailAfterSituation;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-api-3.0.0-20220722.062226-39-sources.jar: com/ejianc/business/bid/vo/BusinessVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 商机登记
 * 
 * @author generator
 * 
 */
public class BusinessVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String projectName; // 招标项目名称
    private String constructionUnit; // 建设单位
    private Long unitnatureId; // 建设单位 性质
    private String unitnatureName; // 建设单位 性质(name)
    private String unitnatureCode; // 建设单位 性质(name)
    private String projectScale; // 项目规模
    private BigDecimal investmentVolume; // 投资额
    private BigDecimal civilErectionCost; // 投资额
    private Long bidUnitId; // 申请单位
    private String bidUnitName; // 申请单位 名称
    private String bidUnitCode; // 申请单位 编码
    private String implementModel; // 实施模式
    private Long projectTypeId; // 项目类别
    private String projectTypeName; // 项目类别名称
    private String projectTypeCode; // 项目类型编码
    private String projectLever; // 项目跟踪等级
    private String projectLeverName; // 项目跟踪等级
    private Long sourceProjectType; // 项目来源
    private String sourceProjectTypeName; // 项目来源
    private String detailedAddress; // 详细地址
    private String area; // 区域
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date bidPlanOpenDate; // 预计开标日期
    private String projectStatus; // 项目状态
    private String employeeCode; // 项目跟踪人编码
    private String employeeName; // 项目跟踪人名称
    private String employeePhone; // 项目跟踪人电话

    private Long employeeId; // 项目跟踪人
    private String tailAfterSituation; // 项目跟踪情况
    private String projectSituation; // 项目概况
    private String billCode; // 单据编码
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Date commitData; // 提交日期
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    private Integer refFlag; // 是否被引用
    private String addressValue;//详细地址 记录value

    private String changeItem;

    public String getAddressValue() {
        return addressValue;
    }

    public void setAddressValue(String addressValue) {
        this.addressValue = addressValue;
    }

    public String getChangeItem() {
        return changeItem;
    }

    public Integer getRefFlag() {
        return refFlag;
    }

    public void setRefFlag(Integer refFlag) {
        this.refFlag = refFlag;
    }

    public String getProjectTypeCode() {
        return projectTypeCode;
    }

    public void setProjectTypeCode(String projectTypeCode) {
        this.projectTypeCode = projectTypeCode;
    }

    public void setChangeItem(String changeItem) {
        this.changeItem = changeItem;
    }

    public String getEmployeePhone() {
        return employeePhone;
    }

    public void setEmployeePhone(String employeePhone) {
        this.employeePhone = employeePhone;
    }

    private List<BusinessRecordVO> recordList = new ArrayList<>();

    public List<BusinessRecordVO> getRecordList() {
        return recordList;
    }

    public void setRecordList(List<BusinessRecordVO> recordList) {
        this.recordList = recordList;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }
    @ReferDeserialTransfer
    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public BigDecimal getInvestmentVolume() {
        return investmentVolume;
    }

    public void setInvestmentVolume(BigDecimal investmentVolume) {
        this.investmentVolume = investmentVolume;
    }
    public BigDecimal getCivilErectionCost() {
        return civilErectionCost;
    }

    public void setCivilErectionCost(BigDecimal civilErectionCost) {
        this.civilErectionCost = civilErectionCost;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }
    @ReferDeserialTransfer
    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getImplementModel() {
        return implementModel;
    }

    public void setImplementModel(String implementModel) {
        this.implementModel = implementModel;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }
    @ReferDeserialTransfer
    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProjectLever() {
        return projectLever;
    }
    public void setProjectLever(String projectLever) {
        this.projectLever = projectLever;
    }
    public String getProjectLeverName() {
        return projectLeverName;
    }

    public void setProjectLeverName(String projectLeverName) {
        this.projectLeverName = projectLeverName;
    }
    public Long getSourceProjectType() {
        return sourceProjectType;
    }
    @ReferDeserialTransfer
    public void setSourceProjectType(Long sourceProjectType) {
        this.sourceProjectType = sourceProjectType;
    }
    public String getSourceProjectTypeName() {
        return sourceProjectTypeName;
    }

    public void setSourceProjectTypeName(String sourceProjectTypeName) {
        this.sourceProjectTypeName = sourceProjectTypeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Date getBidPlanOpenDate() {
        return bidPlanOpenDate;
    }

    public void setBidPlanOpenDate(Date bidPlanOpenDate) {
        this.bidPlanOpenDate = bidPlanOpenDate;
    }
    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getTailAfterSituation() {
        return tailAfterSituation;
    }

    public void setTailAfterSituation(String tailAfterSituation) {
        this.tailAfterSituation = tailAfterSituation;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
